@@ -45,7 +45,7 @@ def install_requirements():
     os.system(f"{source}{activate_file} && pip install -r requirements.txt")
 
 @app.command()
-def main():
+def main(template_name):
     cookiecutter("https://github.com/MohammedBajuaifer/drf-starter-templates.git")
 
     install_requirements()
